# Poker Stats #
[![Build Status](https://api.travis-ci.org/yarpenzigrin/pokerstats.svg?branch=develop)](https://travis-ci.org/yarpenzigrin/pokerstats?branch=develop)

## Features ##
Poker Stats takes poker hand history saved by PokerStars client and generates statistics for profiling player's game. Available reports include:
* position report showing statistics and profit broke down per position at the table e. g. button raise and winrate
* holding report where user can see end result of playing specific hands e. g. ace-king offsuit
* preflop report focusing on success of preflop steals, 3-bets and 4-bets
* blind play report

Additionaly dump option allows users to filter out undesired hands from the original set for further processing (e. g. hand review in the replayer).

## Installation ##
[Get Poker Stats from PyPi](https://pypi.org/project/poker_stats)

## Authors ##
Michał Nowak
Damian Szuberski
